Learn R Programming

eurocordexr (version 0.2.4)

compare_variables_in_inventory: Compare an EURO-CORDEX inventory for different variables

Description

Casts the result from get_inventory for different variables in order to compare completeness of the inventory. Adds columns for checking equality of years and number of files.

Usage

compare_variables_in_inventory(data_inventory, vars = NULL)

Value

The casted data.table with boolean columns if all years and number of files are equal for all variables.

Arguments

data_inventory

A data.table as resulting from get_inventory.

vars

Character vector of variables to compare. If NULL, will use all variables in data_inventory.

Examples

Run this code
if (FALSE) {

path <- "/mnt/CEPH_BASEDATA/METEO/SCENARIO"
dat <- get_inventory(path)
dat_compare <- compare_variables_in_inventory(dat, c("tas","rsds","pr"))
}

Run the code above in your browser using DataLab